searchData={"items":[{"type":"module","title":"Crc64","doc":"[![Hex version badge](https://img.shields.io/hexpm/v/crc_64.svg)](https://hex.pm/packages/crc_64)\n[![Test](https://github.com/MikaAK/crc_64/actions/workflows/test.yml/badge.svg)](https://github.com/MikaAK/crc_64/actions/workflows/test.yml)\n[![Credo](https://github.com/MikaAK/crc_64/actions/workflows/credo.yml/badge.svg)](https://github.com/MikaAK/crc_64/actions/workflows/credo.yml)\n[![Dialyzer](https://github.com/MikaAK/crc_64/actions/workflows/dialyzer.yml/badge.svg)](https://github.com/MikaAK/crc_64/actions/workflows/dialyzer.yml)\n[![Coverage](https://github.com/MikaAK/crc_64/actions/workflows/coverage.yml/badge.svg)](https://github.com/MikaAK/crc_64/actions/workflows/coverage.yml)\n\n\nImplements AWS S3 compatible CRC64-NVME checksum calculation.\nPure Elixir implementation with no external dependencies.\n\nCRC64 is a 64-bit cyclic redundancy check algorithm used for error detection.\nThis implementation uses the polynomial 0x9A6C9329AC4BC9B5 which is compatible\nwith AWS S3's CRC64 implementation.","ref":"Crc64.html"},{"type":"module","title":"Installation - Crc64","doc":"[Available in Hex](https://hex.pm/packages/crc_64), the package can be installed\nby adding `crc_64` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:crc_64, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"Crc64.html#module-installation"},{"type":"module","title":"Usage - Crc64","doc":"","ref":"Crc64.html#module-usage"},{"type":"module","title":"Calculate CRC64 Checksum (as integer) - Crc64","doc":"```elixir\n# Calculate checksum for a binary\nchecksum = Crc64.calculate(\"Hello, world!\")\n# Returns a non-negative integer\n```","ref":"Crc64.html#module-calculate-crc64-checksum-as-integer"},{"type":"module","title":"Calculate CRC64 Checksum (as Base64 string) - Crc64","doc":"```elixir\n# Calculate Base64-encoded checksum\nbase64_checksum = Crc64.calculate_base64(\"Hello, world!\")\n# Returns a Base64 string like \"Ik7A4/gH+LE=\"\n```","ref":"Crc64.html#module-calculate-crc64-checksum-as-base64-string"},{"type":"module","title":"Validate Data against Checksum - Crc64","doc":"```elixir\n# Check if data matches a checksum\ndata = \"Important content\"\nchecksum = \"dGhlIGNoZWNrc3VtIGhlcmU=\" # previously calculated Base64 checksum\nis_valid = Crc64.valid_checksum?(data, checksum)\n# Returns true if the calculated checksum matches\n```","ref":"Crc64.html#module-validate-data-against-checksum"},{"type":"module","title":"Validate File against Checksum - Crc64","doc":"```elixir\n# Validate a file against a known checksum\nfile_path = \"path/to/your/file.txt\"\nchecksum = \"dGhlIGNoZWNrc3VtIGhlcmU=\" # previously calculated Base64 checksum\nis_valid = Crc64.valid_file_checksum?(file_path, checksum)\n# Returns true if the file's checksum matches\n```\n\nDocumentation can be found at  .","ref":"Crc64.html#module-validate-file-against-checksum"},{"type":"function","title":"Crc64.calculate/1","doc":"Calculates the CRC64 checksum for the given binary data.\n\nReturns the checksum as an integer value.","ref":"Crc64.html#calculate/1"},{"type":"function","title":"Examples - Crc64.calculate/1","doc":"iex> Crc64.calculate(\"123456789\")\n    0xAE8B14860A799888","ref":"Crc64.html#calculate/1-examples"},{"type":"function","title":"Crc64.calculate_base64/1","doc":"Calculates the CRC64 checksum for the given binary data and returns it as a Base64 encoded string.\n\nThis format is compatible with the AWS S3 CRC64 checksums.","ref":"Crc64.html#calculate_base64/1"},{"type":"function","title":"Examples - Crc64.calculate_base64/1","doc":"iex> Crc64.calculate_base64(\"Hello World!\")\n    \"AuUcyF784aU=\"","ref":"Crc64.html#calculate_base64/1-examples"},{"type":"function","title":"Crc64.valid_checksum?/2","doc":"Validates if the given checksum matches the calculated checksum for the data.\n\nReturns `true` if the checksum is valid, `false` otherwise.","ref":"Crc64.html#valid_checksum?/2"},{"type":"function","title":"Examples - Crc64.valid_checksum?/2","doc":"iex> Crc64.valid_checksum?(\"Hello World!\", \"AuUcyF784aU=\")\n    true\n\n    iex> Crc64.valid_checksum?(\"Hello World!\", \"u5WU6IUEP4mKJw==\")\n    false","ref":"Crc64.html#valid_checksum?/2-examples"},{"type":"function","title":"Crc64.valid_file_checksum?/2","doc":"Validates if the given checksum matches the calculated checksum for the file contents.\n\nReturns `true` if the checksum is valid, `false` otherwise.\nRaises an error if the file does not exist or cannot be read.","ref":"Crc64.html#valid_file_checksum?/2"},{"type":"function","title":"Examples - Crc64.valid_file_checksum?/2","doc":"iex> File.write!(\"test.txt\", \"Hello World!\")\n    :ok\n    iex> Crc64.valid_file_checksum?(\"test.txt\", \"AuUcyF784aU=\")\n    true\n    iex> File.rm!(\"test.txt\")\n    :ok","ref":"Crc64.html#valid_file_checksum?/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}